"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    cacheHash: ()=>cacheHash,
    cacheFetch: ()=>cacheFetch,
    cachePut: ()=>cachePut
});
const _cacheConfig = require("./cacheConfig");
const _logger = require("../logger");
const _salt = require("./salt");
const _api = /*#__PURE__*/ _interopRequireWildcard(require("backfill/lib/api"));
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {};
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
async function cacheHash(id, cwd, root, cacheOptions, args) {
    const cacheConfig = (0, _cacheConfig.getCacheConfig)(cwd, cacheOptions);
    const backfillLogger = _api.makeLogger("error", process.stdout, process.stderr);
    const hashKey = (0, _salt.salt)(cacheOptions.environmentGlob || [
        "lage.config.js"
    ], `${id}|${JSON.stringify(args)}`, root, cacheOptions.cacheKey);
    backfillLogger.setName(id);
    try {
        return await _api.computeHash(cwd, backfillLogger, hashKey, cacheConfig);
    } catch  {
    // computeHash can throw exception when git is not installed or the repo hashes cannot be calculated with a staged file that is deleted
    // lage will continue as if this package cannot be cached
    }
    return null;
}
async function cacheFetch(hash, id, cwd, cacheOptions) {
    if (!hash) {
        return false;
    }
    const cacheConfig = (0, _cacheConfig.getCacheConfig)(cwd, cacheOptions);
    const backfillLogger = _api.makeLogger("error", process.stdout, process.stderr);
    try {
        return await _api.fetch(cwd, hash, backfillLogger, cacheConfig);
    } catch (e) {
        _logger.logger.error(`${id} fetchBackfill ${e && e.stack || e && e.message || e}`);
    }
    return false;
}
async function cachePut(hash, cwd, cacheOptions) {
    if (!hash) {
        return;
    }
    const cacheConfig = (0, _cacheConfig.getCacheConfig)(cwd, cacheOptions);
    const backfillLogger = _api.makeLogger("warn", process.stdout, process.stderr);
    try {
        await _api.put(cwd, hash, backfillLogger, cacheConfig);
    } catch (e) {
    // sometimes outputGlob don't match any files, so skipping this
    }
}
