"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "getCacheConfig", {
    enumerable: true,
    get: ()=>getCacheConfig
});
const _backfillConfig = require("backfill-config");
const _backfillLogger = require("backfill-logger");
const _isRunningFromCI = require("../isRunningFromCI");
const _remoteFallbackCacheProvider = require("./RemoteFallbackCacheProvider");
function getCacheConfig(cwd, cacheOptions) {
    const defaultCacheConfig = (0, _backfillConfig.createDefaultConfig)(cwd);
    // in lage, default mode is to CACHE locally
    defaultCacheConfig.cacheStorageConfig.provider = "local";
    const logger = (0, _backfillLogger.makeLogger)("warn");
    const envConfig = (0, _backfillConfig.getEnvConfig)(logger);
    const configWithEnvOverrides = {
        ...defaultCacheConfig,
        ...cacheOptions,
        ...envConfig,
        writeRemoteCache: cacheOptions.writeRemoteCache || !!process.env.LAGE_WRITE_REMOTE_CACHE || _isRunningFromCI.isRunningFromCI,
        skipLocalCache: cacheOptions.skipLocalCache ?? _isRunningFromCI.isRunningFromCI
    };
    const configWithFallback = {
        ...configWithEnvOverrides,
        cacheStorageConfig: {
            ...configWithEnvOverrides.cacheStorageConfig,
            provider: (logger, cwd)=>new _remoteFallbackCacheProvider.RemoteFallbackCacheProvider(configWithEnvOverrides, logger, cwd),
            name: "remote-fallback-provider"
        }
    };
    return configWithFallback;
}
