"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _getConfig = require("./config/getConfig");
const _init = require("./command/init");
const _run = require("./command/run");
const _showHelp = require("./showHelp");
const _logger = require("./logger");
const _info = require("./command/info");
const _initReporters = require("./logger/initReporters");
const _version = require("./command/version");
const _cache = require("./command/cache");
const _graph = require("./command/graph");
// Parse CLI args
const cwd = process.cwd();
try {
    const config = (0, _getConfig.getConfig)(cwd);
    const reporters = (0, _initReporters.initReporters)(config);
    switch(config.command[0]){
        case "cache":
            (0, _cache.cache)(cwd, config);
            break;
        case "init":
            (0, _init.init)(cwd);
            break;
        case "info":
            (0, _info.info)(cwd, config);
            break;
        case "graph":
            (0, _graph.graph)(cwd);
            break;
        case "version":
            (0, _version.version)();
            break;
        default:
            _logger.logger.info(`Lage task runner - let's make it`);
            (0, _run.run)(cwd, config, reporters);
            break;
    }
} catch (e) {
    (0, _showHelp.showHelp)(e && e.message);
}
