"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "info", {
    enumerable: true,
    get: ()=>info
});
const _logger = require("../logger");
const _getWorkspace = require("../workspace/getWorkspace");
const _getPipelinePackages = require("../task/getPipelinePackages");
const _path = /*#__PURE__*/ _interopRequireDefault(require("path"));
const _getNpmCommand = require("../task/getNpmCommand");
const _pipeline = require("../task/Pipeline");
const _taskId = require("../task/taskId");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
async function info(cwd, config) {
    const workspace = (0, _getWorkspace.getWorkspace)(cwd, config);
    const packages = (0, _getPipelinePackages.getPipelinePackages)(workspace, config);
    const pipeline = new _pipeline.Pipeline(workspace, config);
    const targetGraph = pipeline.generateTargetGraph();
    const packageTasks = new Map();
    for (const [from, to] of targetGraph){
        for (const id of [
            from,
            to
        ]){
            if (!packageTasks.has(id)) {
                const packageTaskInfo = createPackageTaskInfo(id, config, workspace);
                if (packageTaskInfo && id !== _pipeline.START_TARGET_ID) {
                    packageTasks.set(id, packageTaskInfo);
                }
            }
        }
        if (packageTasks.has(to) && from !== _pipeline.START_TARGET_ID) {
            packageTasks.get(to).dependencies.push(from);
        }
    }
    _logger.logger.info(`info`, {
        command: config.command.slice(1),
        scope: packages,
        packageTasks: [
            ...packageTasks.values()
        ]
    });
}
function createPackageTaskInfo(id, config, workspace) {
    const { packageName , task  } = (0, _taskId.getPackageAndTask)(id);
    if (packageName) {
        const info = workspace.allPackages[packageName];
        if (!!info.scripts?.[task]) {
            return {
                id,
                command: [
                    config.npmClient,
                    ...(0, _getNpmCommand.getNpmCommand)(config.node, config.args, task)
                ],
                dependencies: [],
                workingDirectory: _path.default.relative(workspace.root, _path.default.dirname(workspace.allPackages[packageName].packageJsonPath)).replace(/\\/g, "/"),
                package: packageName,
                task
            };
        }
    } else {
        return {
            id,
            command: [
                "echo",
                `"global script ${id}"`
            ],
            dependencies: [],
            workingDirectory: ".",
            package: undefined,
            task
        };
    }
}
