"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "run", {
    enumerable: true,
    get: ()=>run
});
const _getWorkspace = require("../workspace/getWorkspace");
const _logger = require("../logger");
const _abortSignal = require("../task/abortSignal");
const _displayReportAndExit = require("../displayReportAndExit");
const _context = require("../context");
const _npmScriptTask = require("../task/NpmScriptTask");
const _pipeline = require("../task/Pipeline");
async function run(cwd, config, reporters) {
    const context = (0, _context.createContext)(config);
    const workspace = (0, _getWorkspace.getWorkspace)(cwd, config);
    const { profiler  } = context;
    let aborted = false;
    context.measures.start = process.hrtime();
    // die faster if an abort signal is seen
    _abortSignal.signal.addEventListener("abort", async ()=>{
        aborted = true;
        _npmScriptTask.NpmScriptTask.killAllActiveProcesses();
        (0, _displayReportAndExit.displayReportAndExit)(reporters, context);
    });
    try {
        const pipeline = new _pipeline.Pipeline(workspace, config);
        await pipeline.run(context);
    } catch (e) {
        process.exitCode = 1;
        if (e && e.stack) {
            _logger.logger.error("runTasks: " + e.stack);
        } else if (e && e.message) {
            _logger.logger.error("runTasks: " + e.message);
        } else {
            _logger.logger.error("runTasks: " + e);
        }
    }
    if (config.profile) {
        try {
            const profileFile = profiler.output();
            _logger.logger.info(`runTasks: Profile saved to ${profileFile}`);
        } catch (e1) {
            process.exitCode = 1;
            if (e1 && e1.message) {
                _logger.logger.error(`An error occured while trying to write profile: ${e1.message}`);
            }
        }
    }
    if (!aborted) {
        (0, _displayReportAndExit.displayReportAndExit)(reporters, context);
    }
}
