"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "Logger", {
    enumerable: true,
    get: ()=>Logger
});
const _logLevel = require("./LogLevel");
const _npmLogReporter = require("./reporters/NpmLogReporter");
class Logger {
    log(level, msg, data) {
        const entry = {
            timestamp: Date.now(),
            level,
            msg,
            data
        };
        this.logs.push(entry);
        for (const reporter of Logger.reporters){
            reporter.log(entry);
        }
    }
    info(msg, data) {
        this.log(_logLevel.LogLevel.info, msg, data);
    }
    warn(msg, data) {
        this.log(_logLevel.LogLevel.warn, msg, data);
    }
    error(msg, data) {
        this.log(_logLevel.LogLevel.error, msg, data);
    }
    verbose(msg, data) {
        this.log(_logLevel.LogLevel.verbose, msg, data);
    }
    silly(msg, data) {
        this.log(_logLevel.LogLevel.silly, msg, data);
    }
    constructor(){
        this.logs = [];
    }
}
Logger.reporters = [
    new _npmLogReporter.NpmLogReporter({
        logLevel: _logLevel.LogLevel.info
    })
];
