"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "initReporters", {
    enumerable: true,
    get: ()=>initReporters
});
const _logger = require("./Logger");
const _npmLogReporter = require("./reporters/NpmLogReporter");
const _logLevel = require("./LogLevel");
const _jsonReporter = require("./reporters/JsonReporter");
const _adoReporter = require("./reporters/AdoReporter");
const _dgmlReporter = require("./reporters/DgmlReporter");
function initReporters(config) {
    // Initialize logger
    let logLevel = config.verbose ? _logLevel.LogLevel.verbose : _logLevel.LogLevel.info;
    if (config.logLevel) {
        logLevel = _logLevel.LogLevel[config.logLevel];
    }
    const reporters = [
        config.reporter === "json" ? new _jsonReporter.JsonReporter({
            logLevel
        }) : config.reporter === "dgml" ? new _dgmlReporter.DgmlReporter() : new _npmLogReporter.NpmLogReporter({
            logLevel,
            grouped: config.grouped,
            npmLoggerOptions: config.loggerOptions
        })
    ];
    if (config.reporter === "adoLog") {
        // Will always include NpmLogReporter and add AdoReporter
        reporters.push(new _adoReporter.AdoReporter());
    }
    _logger.Logger.reporters = reporters;
    return reporters;
}
