"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "DgmlReporter", {
    enumerable: true,
    get: ()=>DgmlReporter
});
const _xmldom = /*#__PURE__*/ _interopRequireDefault(require("@xmldom/xmldom"));
const _logLevel = require("../LogLevel");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
class DgmlReporter {
    log(entry) {
        if (entry.msg == "info" && entry.level == _logLevel.LogLevel.info && entry.data) {
            const packageTasks = entry.data.packageTasks;
            if (packageTasks) {
                const dgmlDoc = new _xmldom.default.DOMImplementation().createDocument("http://schemas.microsoft.com/vs/2009/dgml", "DirectedGraph");
                const directedGraph = dgmlDoc.documentElement;
                directedGraph.setAttribute("GraphDirection", "LeftToRight");
                const nodes = dgmlDoc.createElement("Nodes");
                const links = dgmlDoc.createElement("Links");
                const categories = dgmlDoc.createElement("Categories");
                directedGraph.appendChild(nodes);
                directedGraph.appendChild(links);
                directedGraph.appendChild(categories);
                const visitedCategories = new Set();
                for (var packageTask of packageTasks){
                    // Node
                    const node = dgmlDoc.createElement("Node");
                    node.setAttribute("Id", packageTask.id);
                    node.setAttribute("Label", packageTask.id);
                    nodes.appendChild(node);
                    const category = dgmlDoc.createElement("Category");
                    category.setAttribute("Ref", packageTask.task);
                    node.appendChild(category);
                    // Links
                    for (var dependencyId of packageTask.dependencies){
                        const link = dgmlDoc.createElement("Link");
                        link.setAttribute("Source", packageTask.id);
                        link.setAttribute("Target", dependencyId);
                        links.appendChild(link);
                    }
                    // Category
                    if (!visitedCategories.has(packageTask.task)) {
                        visitedCategories.add(packageTask.task);
                        const category1 = dgmlDoc.createElement("Category");
                        category1.setAttribute("Id", packageTask.task);
                        category1.setAttribute("Label", packageTask.task);
                        categories.appendChild(category1);
                    }
                }
                const dgmlContents = new _xmldom.default.XMLSerializer().serializeToString(dgmlDoc);
                console.log(dgmlContents);
            }
        }
    }
    summarize(context) {}
    constructor(){}
}
