"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "JsonReporter", {
    enumerable: true,
    get: ()=>JsonReporter
});
const _formatDuration = require("./formatDuration");
class JsonReporter {
    log(entry) {
        if (this.options.logLevel >= entry.level) {
            console.log(JSON.stringify(entry));
        }
    }
    summarize(context) {
        const { measures , targets  } = context;
        const summary = {};
        const taskStats = [];
        for (const wrappedTarget of targets.values()){
            taskStats.push({
                package: wrappedTarget.target.packageName,
                task: wrappedTarget.target.task,
                duration: (0, _formatDuration.hrToSeconds)(wrappedTarget.duration),
                status: wrappedTarget.status
            });
        }
        if (measures.failedTargets && measures.failedTargets.length > 0) {
            summary.failedTargets = measures.failedTargets;
        }
        summary.duration = (0, _formatDuration.hrToSeconds)(measures.duration);
        summary.taskStats = taskStats;
        console.log(JSON.stringify({
            summary
        }));
    }
    constructor(options){
        this.options = options;
    }
}
