"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "NpmScriptTask", {
    enumerable: true,
    get: ()=>NpmScriptTask
});
const _findNpmClient = require("../workspace/findNpmClient");
const _childProcess = require("child_process");
const _path = /*#__PURE__*/ _interopRequireDefault(require("path"));
const _getNpmCommand = require("./getNpmCommand");
const _logLevel = require("../logger/LogLevel");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
class NpmScriptTask {
    static killAllActiveProcesses() {
        // first, send SIGTERM everywhere
        for (const cp of NpmScriptTask.activeProcesses){
            cp.kill("SIGTERM");
        }
        // wait for "gracefulKillTimeout" to make sure everything is terminated via SIGKILL
        setTimeout(()=>{
            for (const cp of NpmScriptTask.activeProcesses){
                if (!cp.killed) {
                    cp.kill("SIGKILL");
                }
            }
        }, NpmScriptTask.gracefulKillTimeout);
    }
    run() {
        const { info , logger , npmArgs  } = this;
        const { npmCmd  } = NpmScriptTask;
        return new Promise((resolve, reject)=>{
            logger.verbose(`Running ${[
                npmCmd,
                ...npmArgs
            ].join(" ")}`);
            const cp = (0, _childProcess.spawn)(npmCmd, npmArgs, {
                cwd: _path.default.dirname(info.packageJsonPath),
                stdio: "pipe",
                env: {
                    ...process.env,
                    ...process.stdout.isTTY && this.config.reporter !== "json" && {
                        FORCE_COLOR: "1"
                    },
                    LAGE_PACKAGE_NAME: info.name
                }
            });
            NpmScriptTask.activeProcesses.add(cp);
            this.logger.stream(_logLevel.LogLevel.verbose, cp.stdout);
            this.logger.stream(_logLevel.LogLevel.verbose, cp.stderr);
            cp.on("exit", handleChildProcessExit);
            function handleChildProcessExit(code) {
                if (code === 0) {
                    NpmScriptTask.activeProcesses.delete(cp);
                    return resolve();
                }
                logger.verbose(`Exiting ${[
                    npmCmd,
                    ...npmArgs
                ].join(" ")} with exit code ${code}`);
                cp.stdout.destroy();
                cp.stdin.destroy();
                reject();
            }
        });
    }
    constructor(task, info, config, logger){
        this.task = task;
        this.info = info;
        this.config = config;
        this.logger = logger;
        this.npmArgs = [];
        this.startTime = [
            0,
            0
        ];
        this.duration = [
            0,
            0
        ];
        NpmScriptTask.npmCmd = NpmScriptTask.npmCmd || (0, _findNpmClient.findNpmClient)(config.npmClient);
        this.npmArgs = (0, _getNpmCommand.getNpmCommand)(config.node, config.args, task);
    }
}
NpmScriptTask.npmCmd = "";
NpmScriptTask.activeProcesses = new Set();
NpmScriptTask.gracefulKillTimeout = 2500;
