"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "filterPackages", {
    enumerable: true,
    get: ()=>filterPackages
});
const _workspaceTools = require("workspace-tools");
const _logger = require("../logger");
function filterPackages(options) {
    const { scopedPackages , changedPackages , allPackages , deps , includeDependencies  } = options;
    let filtered = [];
    // If scope is defined, use the transitive providers of the since packages up to the scope
    if (typeof scopedPackages !== "undefined" && typeof changedPackages !== "undefined") {
        // If both scoped and since are specified, we have to merge two lists:
        // 1. changed packages that ARE themselves the scoped packages
        // 2. changed package consumers (package dependents) that are within the scoped subgraph
        filtered = changedPackages.filter((pkg)=>scopedPackages.includes(pkg)).concat((0, _workspaceTools.getTransitiveConsumers)(changedPackages, allPackages, scopedPackages));
        _logger.logger.verbose(`filterPackages changed within scope: ${filtered.join(",")}`);
    } else if (typeof changedPackages !== "undefined") {
        filtered = [
            ...changedPackages
        ];
        _logger.logger.verbose(`filterPackages changed: ${changedPackages.join(",")}`);
    } else if (typeof scopedPackages !== "undefined") {
        filtered = [
            ...scopedPackages
        ];
        _logger.logger.verbose(`filterPackages scope: ${scopedPackages.join(",")}`);
    } else {
        filtered = Object.keys(allPackages);
    }
    // adds dependents (consumers) of all filtered package thus far
    if (deps) {
        _logger.logger.verbose(`filterPackages running with dependents`);
        filtered = filtered.concat((0, _workspaceTools.getTransitiveConsumers)(filtered, allPackages));
    }
    // adds dependencies of all filtered package thus far
    if (includeDependencies) {
        filtered = filtered.concat((0, _workspaceTools.getTransitiveDependencies)(filtered, allPackages));
    }
    const unique = new Set(filtered);
    return [
        ...unique
    ];
}
