"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "getPipelinePackages", {
    enumerable: true,
    get: ()=>getPipelinePackages
});
const _filterPackages = require("./filterPackages");
const _workspaceTools = require("workspace-tools");
const _fastGlob = /*#__PURE__*/ _interopRequireWildcard(require("fast-glob"));
const _logger = require("../logger");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {};
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
function getPipelinePackages(workspace, config) {
    const { scope , since , repoWideChanges , includeDependencies  } = config;
    // If scoped is defined, get scoped packages
    const hasScopes = Array.isArray(scope) && scope.length > 0;
    let scopedPackages = undefined;
    if (hasScopes) {
        scopedPackages = (0, _workspaceTools.getScopedPackages)(scope, workspace.allPackages);
    }
    const hasSince = typeof since !== "undefined";
    let changedPackages = undefined;
    // Be specific with the changed packages only if no repo-wide changes occurred
    if (hasSince && !hasRepoChanged(since, workspace.root, repoWideChanges)) {
        try {
            changedPackages = (0, _workspaceTools.getChangedPackages)(workspace.root, since, config.ignore);
        } catch (e) {
            _logger.logger.warn(`An error in the git command has caused this scope run to include every package\n${e}`);
        // if getChangedPackages throws, we will assume all have changed (using changedPackage = undefined)
        }
    }
    return (0, _filterPackages.filterPackages)({
        allPackages: workspace.allPackages,
        deps: config.deps,
        scopedPackages,
        changedPackages,
        includeDependencies
    });
}
function hasRepoChanged(since, root, environmentGlob) {
    try {
        const changedFiles = (0, _workspaceTools.getBranchChanges)(since, root);
        const envFiles = _fastGlob.sync(environmentGlob, {
            cwd: root
        });
        let repoWideChanged = false;
        if (changedFiles) {
            for (const change of changedFiles){
                if (envFiles.includes(change)) {
                    repoWideChanged = true;
                    break;
                }
            }
        }
        return repoWideChanged;
    } catch (e) {
        // if this fails, let's assume repo has changed
        _logger.logger.warn(`An error in the git command has caused this to consider the repo has changed\n${e}`);
        return true;
    }
}
